package com.atguigu.config;

import com.atguigu.interceptor.LoginAuthInterceptor;
import com.atguigu.interceptor.UserLoginAuthInterceptor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.servlet.config.annotation.CorsRegistry;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

@Slf4j
public class WebMvcConfiguration implements WebMvcConfigurer {
    @Autowired
    private LoginAuthInterceptor loginAuthInterceptor;
    @Autowired
    private UserLoginAuthInterceptor userLoginAuthInterceptor;

    /**
     * * 解决跨域
     *
     * @param registry 跨域注册表
     */
    @Override
    public void addCorsMappings(CorsRegistry registry) {
        log.info("WebMvcConfiguration===>开始跨域注册表...");

        registry.addMapping("/admin/**")// 添加路径规则
                .allowCredentials(true)// 是否允许在跨域的情况下传递Cookie
                .allowedOriginPatterns("*")// 允许请求来源的域规则
                .allowedMethods("*").allowedHeaders("*");// 允许所有的请求头
    }

    /**
     * 注册自定义拦截器
     *
     * @param registry InterceptorRegistry
     */
    @Override
    public void addInterceptors(InterceptorRegistry registry) {
        log.info("WebMvcConfiguration===>开始注册自定义拦截器...");

        // 拦截后台管理内容
        String[] loginAuthInterceptors = {"/admin/system/index/login", "/admin/system/index/generateValidateCode", "/admin/product/category/exportData"};
        registry.addInterceptor(loginAuthInterceptor).addPathPatterns("/admin/**")
                .excludePathPatterns(loginAuthInterceptors);

        // 拦截前台内容
        registry.addInterceptor(userLoginAuthInterceptor).addPathPatterns("/api/**");
    }
}