package com.atguigu.spzx.manger.service.impl;

import com.atguigu.constant.MessageConstant;
import com.atguigu.spzx.manger.mapper.BrandMapper;
import com.atguigu.spzx.manger.service.BrandService;
import com.atguigu.spzx.model.entity.product.Brand;
import com.atguigu.utils.EmptyUtil;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class BrandServiceImpl implements BrandService {
    @Autowired
    private BrandMapper brandMapper;
    @Autowired
    private EmptyUtil emptyUtil;

    /**
     * 品牌列表查询
     *
     * @param page  当前页
     * @param limit 每页大小
     * @return 品牌分页结果
     */
    @Override
    public PageInfo<Brand> findByPage(Integer page, Integer limit) {
        Page<Brand> startPage = PageHelper.startPage(page, limit);

        // 查找分页品牌
        List<Brand> brandList = brandMapper.findByPage();
        startPage.close();
        return new PageInfo<>(brandList);
    }

    /**
     * 品牌添加
     *
     * @param brand 品牌实体类
     */
    @Override
    public void save(Brand brand) {
        brandMapper.save(brand);
    }

    /**
     * 修改品牌
     *
     * @param brand 品牌实体类
     */
    @Override
    public void updateById(Brand brand) {
        // 插入时不能为空
        emptyUtil.isEmpty(brand, MessageConstant.DELETE_ID_IS_NOT_EMPTY);

        brandMapper.updateById(brand);
    }

    /**
     * 根据id删除品牌
     *
     * @param id 品牌id
     */
    @Override
    public void deleteById(Long id) {
        // 判断ID不能为空
        emptyUtil.isEmpty(id, MessageConstant.DELETE_ID_IS_NOT_EMPTY);

        brandMapper.deleteById(id);
    }

    /**
     * 品牌列表
     *
     * @return 品牌列表
     */
    @Override
    public List<Brand> findAll() {
        return brandMapper.findAll();
    }
}
