package com.atguigu.user.service.impl;

import com.atguigu.constant.MessageConstant;
import com.atguigu.context.BaseContext;
import com.atguigu.exception.BunnyException;
import com.atguigu.spzx.model.entity.user.UserAddress;
import com.atguigu.user.mapper.UserAddressMapper;
import com.atguigu.user.service.UserAddressService;
import com.atguigu.utils.EmptyUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
@Slf4j
public class UserAddressServiceImpl implements UserAddressService {
    @Autowired
    private UserAddressMapper userAddressMapper;
    @Autowired
    private EmptyUtil emptyUtil;

    /**
     * 获取用户地址列表
     *
     * @return 用户地址列表
     */
    @Override
    public List<UserAddress> findUserAddressList() {
        // 查询用户地址栏
        Long userId = BaseContext.getUserInfo().getId();
        if (userId != null) {
            return userAddressMapper.selectByUserId(userId);
        }
        throw new BunnyException(MessageConstant.FIND_ID_IS_NOT_EMPTY);
    }

    /**
     * 获取地址信息
     *
     * @param id 地址Id
     * @return 地址信息
     */
    @Override
    public UserAddress getById(Long id) {
        emptyUtil.isEmpty(id, MessageConstant.FIND_ID_IS_NOT_EMPTY);
        return userAddressMapper.getById(id);
    }
}
